
*:*****************************************************************************
*:
*:        Program: TEXT2PRG.PRG
*:
*:         Author: Jerry Rhoads
*:    Copyright (c) 1993, Jerry Rhoads
*:
*:*****************************************************************************
*
* TEXT2PRG is a simple program that converts a text file to a PRG file.
* The program reads each line of the source file, formats the line into
* an "@ x, y say" statement and outputs it to a destination file.
*
* TEXT2PRG was written to convert Logo Screens and other text screens
* designed with an ASCII paint program to a PRG file.
*
* To compile with Clipper's RTLINK, use the command: CL TEXT2PRG
*
* TEXT2PRG accepts four pramaters.  Only the first is necessary.
*
*       FILESOURCE -- Name of source file without extension
*
*       FILEOUT    -- Name of destination file without extension
*                     If not specified uses filesource and adds
*                     PRG extension
*
*       TOPROW    --  Screen location at which to print first row.
*                     Defaults to 0.
*
*       LEFTCOL   --  Screen location at which to print first col.
*                     Defaults to 0.
*
*
* As an example, included in this ZIP is a text screen named LOGO.TXT.
* After compiling TEXT2PRG, enter the DOS command
*
*            TEXT2PRG LOGO
*
* The program will create LOGO.PRG with starting coordinates of 0,0.
*
* Alternately, the DOS command
*
*          TEXT2PRG LOGO LOGONEW 10 10
*
* will create LOGONEW.PRG with starting coordinates of 10, 10.  Please note
* that command line parameters are NOT seperated with commas; however a 
* comma may be used as a place holder for output name as in the following
* example:
*
*          TEXT2PRG LOGO , 5 1
*
* which will create an output file with the same name as in input file 
* (except for the extension) and with starting coordinates of 5,1.
*
* Each line displays on the screen as it is being written to the output file.
* Note however, that the "@ x, y say" command uses 24 spaces.  If the line,
* including the "@ x, y say" is longer that the screen width, all of the 
* will not display.  The entire line will, however, be written to the 
* output file.
*
* Theoratically, this program should accept source files upto 64K in size.
* Practically, I've tested it with four screenfulls of text without any
* problems.
*
*
*                            DISCLAIMER
*
* Users of TEXT2PRG must accept this disclaimer of warranty:
*
* "TEXT2PRG is supplied as is.  The author disclaims all warranties,
* expressed or implied, including, without limitation, the warranties
* of merchantability and of fitness for any purpose.  The author assumes
* no liability for damages, direct or consequential, which may result
* from the use of TEXT2PRG."
*
*                             SHAREWARE
*
* TEXT2PRG is a "shareware program" and is provided at no charge to the
* user for evaluation.  Feel free to share it with your friends, but please
* do not give it away altered or as part of another system.  The essence of
* "user-supported" software is to provide personal computer users with
* quality software without high prices, and yet to provide incentive for
* programmers to continue to develop new products.
*
* If you find this program useful and find that you are using TEXT2PRG and
* continue to use TEXT2PRG after a reasonable trial period, you must make a
* registration payment of $5 to
*
*                   Jerry Rhoads
*                   P. O. Box 45434
*                   Los Angeles, CA 90045
*                   U.S.A.
*
* The $5 registration fee will license one copy for use on any one computer
* at any one time.  You may install the TEXT2PRG on multiple computers
* provided that it is only used on one at a time.   Additional copies of
* TEXT2PRG may be registered at a 50% discount when registered at the same
* time as the initial copy.  You may use the REGISTER file to register your
* copy of TEXT2PRG.
*
* You are encouraged to pass a copy of TEXT2PRG along to your friends for
* evaluation.  Please encourage them to register their copy if they find that
* they can use it.
*
* The author may be contacted on CompuServe at 72550,3133
*
******************************************************************************

PARAMETER filesource, fileout, toprow, leftcol
LOCAL source, memoname, print_file, firstrow, line, row, position

@ 0, 0 CLEAR
@ 0, 0 to maxrow(), maxcol() double
logo()
inkey(3)
@ 0, 0 clear

source = filesource
IF AT(".", source) > 0
   source = SUBSTR(source, 1, AT(".",  source) -1 )
ENDIF
memoname = MEMOREAD(filesource)

IF fileout = nil .or. fileout = ","
   print_file = source + ".prg"
ELSE
   print_file = fileout + ".prg"
ENDIF


IF toprow <> nil
   rowno = "row = " + toprow
ELSE
   rowno = "row = 0"
ENDIF

IF leftcol <> nil
   colno = "col = " + leftcol
ELSE
   colno = "col = 0"
ENDIF


SET PRINTER TO (print_file)

ROW = 3
firstrow = .T.

position = AT(CHR(13), memoname)

DO WHILE position > 0
   LINE = SUBSTR(memoname, 0, position - 1)
   
   IF firstrow
      
      SET DEVICE TO SCREEN
      @ 0, 0 SAY rowno
      @ 1, 0 SAY colno
      SET DEVICE TO PRINT
      @ 0, 0 SAY rowno
      @ 1, 0 SAY colno
      
      LINE = '@ row      ,  col say " ' + LINE + '" '
      firstrow = .F.
      
   ELSE
      
      LINE = '@ row() + 1,  col say " ' + LINE + '" '
      
   ENDIF
   
   SET DEVICE TO SCREEN
   @ ROW, 0 SAY SUBSTR(LINE, 0, MAXCOL())
   
   SET DEVICE TO PRINT
   @ ROW, 0 SAY LINE
   
   ROW++
   
   memoname = SUBSTR(memoname, position + 2)
   position = AT(CHR(13), memoname)
*   INKEY(.25)  && undelete this line to slow down screen display
ENDDO

IF .NOT. Empty(memoname)
   
   LINE = memoname
   LINE = '@ row() + 1,  col say " ' + LINE + '" '
   
   SET DEVICE TO SCREEN
   @ ROW, 0 SAY SUBSTR(LINE, 0, MAXCOL())
   
   SET DEVICE TO PRINT
   @ ROW, 0 SAY LINE
   @ ROW + 1, 0 SAY ""
   
   SET DEVICE TO SCREEN
   
ENDIF

RETURN nil

function logo

row = 5
col = 1

@ row      ,  col say " " 
@ row() + 1,  col say " " 
@ row() + 1,  col say " " 
@ row() + 1,  col say " " 
@ row() + 1,  col say "             " 
@ row() + 1,  col say "    ߱      ߱  ߱ ߱ ߱ " 
@ row() + 1,  col say "                            " 
@ row() + 1,  col say "              ߱           ۱   " 
@ row() + 1,  col say "                             " 
@ row() + 1,  col say "                                        " 
@ row() + 1,  col say " " 
@ row() + 1,  col say "                                 An xBASE Utility"
@ row() + 1,  col say "                         Copyright 1992 by Jerry Rhoads" 
@ row() + 1,  col say "                                All Rights Reserved"

return NIL